Library
================

You can download jupyter notebook example from `TRXASprefitpack-example <https://github.com/pistack/TRXASprefitpack-example/tree/v0.6.1>`__.

.. toctree::
   :maxdepth: 1

   IRF
   Exp_Conv_IRF
   Dmp_Osc_Conv_IRF
   Rate_Eq
   Fit_Transient_Exp
   Fit_Transient_Both
   Fit_Static_voigt
   Fit_Static_thy